# Generated by Django 1.9 on 2016-11-04 01:06

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("recipes", "0001_initial"),
    ]

    operations = [
        migrations.RenameField(
            model_name="recipeingredient",
            old_name="recipes",
            new_name="recipe",
        ),
        migrations.AlterField(
            model_name="recipeingredient",
            name="unit",
            field=models.CharField(
                choices=[
                    (b"unit", b"Units"),
                    (b"kg", b"Kilograms"),
                    (b"l", b"Litres"),
                    (b"st", b"Shots"),
                ],
                max_length=20,
            ),
        ),
    ]
